@@ -17,18 +17,20 @@ class Config:
     def __init__(self, config_path: Path = None):
         self.config_dir: Path = Path(
             os.getenv(
-                "BACKPLANE_CONIG_DIR", os.path.join(os.getenv("HOME", "~"), ".backplane")
+                "BACKPLANE_CONIG_DIR",
+                os.path.join(os.getenv("HOME", Path.home()), ".backplane"),
             )
         )
         self.default_context: str = "default"
         self.active_context: str = "default"
-        self.domain: str = "127-0-0-1.nip.io"
         self.mail: str = None
         self.default_services: list = ["traefik", "portainer"]
         self.verbose: bool = False
+        self.template_url: str = "https://raw.githubusercontent.com/wearep3r/backplane/master/backplane-templates.json"
         self.ssh_public_key: str = None
         self.ssh_public_key_file: Path = Path(f"{os.getenv('HOME')}/.ssh/id_rsa.pub")
         self.https: bool = False
+        self.domain: str = "127-0-0-1.nip.io"
         self.contexts_dir: Path = os.getenv(
             "BACKPLANE_CONTEXTS_DIR", self.config_dir / "contexts"
         )
