@@ -154,7 +154,7 @@ class Service:
             }
             # Rewrite https config
             if self.config.https:
-                self.attrs = self.options.https
+                self.attrs = self.options["https"]
         elif self.name == "portainer":
             self.attrs = {
                 "image": "portainer/portainer-ce:2.0.0",
